==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebGroupByRowSelectorTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRowSelectorTemplateDetailsDescriptionMetadata } from "./WebGroupByRowSelectorTemplateDetailsDescriptionMetadata";
import { WebGroupByRowSelectorTemplateContextDescription } from "./WebGroupByRowSelectorTemplateContextDescription";
/**
 * @hidden
 */
export let WebGroupByRowSelectorTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupByRowSelectorTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupByRowSelectorTemplateContextDescriptionMetadata.a == null) {
                WebGroupByRowSelectorTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupByRowSelectorTemplateContextDescriptionMetadata.c(WebGroupByRowSelectorTemplateContextDescriptionMetadata.a);
            }
            if (a.j(WebGroupByRowSelectorTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGroupByRowSelectorTemplateContextDescriptionMetadata.a);
            WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupByRowSelectorTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Implicit", "ExportedType:WebGroupByRowSelectorTemplateDetails");
        }
        static d(a) {
            WebGroupByRowSelectorTemplateContextDescriptionMetadata.b(a);
            a.aa("WebGroupByRowSelectorTemplateContext", () => new WebGroupByRowSelectorTemplateContextDescription());
            a.z("WebGroupByRowSelectorTemplateContext", WebGroupByRowSelectorTemplateContextDescriptionMetadata.a);
        }
    }
    WebGroupByRowSelectorTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGroupByRowSelectorTemplateContextDescriptionMetadata, 'WebGroupByRowSelectorTemplateContextDescriptionMetadata');
    WebGroupByRowSelectorTemplateContextDescriptionMetadata.a = null;
    return WebGroupByRowSelectorTemplateContextDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGroupByRowSelectorTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRowSelectorTemplateDetailsDescriptionMetadata } from "./WebGroupByRowSelectorTemplateDetailsDescriptionMetadata";
import { WebGroupByRowSelectorTemplateContextDescription } from "./WebGroupByRowSelectorTemplateContextDescription";
/**
 * @hidden
 */
export let WebGroupByRowSelectorTemplateContextDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupByRowSelectorTemplateContextDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupByRowSelectorTemplateContextDescriptionMetadata.a == null) {
                WebGroupByRowSelectorTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupByRowSelectorTemplateContextDescriptionMetadata.c(WebGroupByRowSelectorTemplateContextDescriptionMetadata.a);
            }
            if (a.k(WebGroupByRowSelectorTemplateContextDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGroupByRowSelectorTemplateContextDescriptionMetadata.a);
            WebGroupByRowSelectorTemplateDetailsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupByRowSelectorTemplateContext");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Implicit", "ExportedType:WebGroupByRowSelectorTemplateDetails");
        }
        static d(a) {
            WebGroupByRowSelectorTemplateContextDescriptionMetadata.b(a);
            a.ac("WebGroupByRowSelectorTemplateContext", () => new WebGroupByRowSelectorTemplateContextDescription());
            a.ab("WebGroupByRowSelectorTemplateContext", WebGroupByRowSelectorTemplateContextDescriptionMetadata.a);
        }
    }
    WebGroupByRowSelectorTemplateContextDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGroupByRowSelectorTemplateContextDescriptionMetadata, 'WebGroupByRowSelectorTemplateContextDescriptionMetadata');
    WebGroupByRowSelectorTemplateContextDescriptionMetadata.a = null;
    return WebGroupByRowSelectorTemplateContextDescriptionMetadata;
})();
